"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getInitialFilterState = getInitialFilterState;
exports.filterCountries = filterCountries;
exports.isValidLanguage = isValidLanguage;
exports.isValidCurrency = isValidCurrency;
exports.isValidRegion = isValidRegion;

var _filter2 = _interopRequireDefault(require("lodash/filter"));

var _every2 = _interopRequireDefault(require("lodash/every"));

var _some2 = _interopRequireDefault(require("lodash/some"));

/**
 * initialize filters state
 * @param filterState
 * @returns {{languages: Array<string>, currencies: Array<string>, regions: Array<string>}}
 */
function getInitialFilterState() {
  var filterState = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return {
    languages: [],
    currencies: [],
    regions: []
  };
}
/**
 * filter results by array of filters
 *
 * @param {Array<object>} countries
 * @param {object} filtersState
 * @param {Boolean} showPricePerNight
 * @returns {Array<object>} filtered results
 */


function filterCountries(_ref) {
  var countries = _ref.countries,
      filtersState = _ref.filtersState;
  var languages = filtersState.languages,
      currencies = filtersState.currencies,
      regions = filtersState.regions;
  return (0, _filter2["default"])(countries, function (country) {
    return (0, _every2["default"])([isValidLanguage(country, languages), isValidCurrency(country, currencies), isValidRegion(country, regions)]);
  });
}
/**
 * is valid language
 * @param {object} country
 * @param {Array<string>} languages
 * @return {boolean}
 */


function isValidLanguage(country, languages) {
  if (!languages.length) return true;
  return (0, _some2["default"])(languages.map(function (language) {
    return country.languages.includes(language);
  }));
}
/**
 * is valid currency
 * @param {object} country
 * @param {Array<string>} currencies
 * @return {boolean}
 */


function isValidCurrency(country, currencies) {
  if (!currencies.length) return true;
  return (0, _some2["default"])(currencies.map(function (currency) {
    return country.currencies.includes(currency);
  }));
}
/**
 * is valid region
 * @param {object} country
 * @param {Array<string>} regions
 * @return {boolean}
 */


function isValidRegion(country, regions) {
  if (!regions.length) return true;
  return regions.includes(country.region);
}