"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.generateFiltersData = generateFiltersData;
exports.generateCurrenciesFilterData = generateCurrenciesFilterData;
exports.generateLanguagesFilterData = generateLanguagesFilterData;
exports.generateRegionsFilterData = generateRegionsFilterData;

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _find2 = _interopRequireDefault(require("lodash/find"));

var _orderBy2 = _interopRequireDefault(require("lodash/orderBy"));

/**
 * generate filters data
 * @param {Array<Object>} countries
 * @returns {{currencies: Array, languages: Array, regions: Array}}
 */
function generateFiltersData(countries) {
  var filtersData = {
    currencies: [],
    languages: [],
    regions: []
  };
  countries.forEach(function (country) {
    var languages = country.languages,
        currencies = country.currencies,
        region = country.region;
    filtersData.currencies = generateCurrenciesFilterData(filtersData.currencies, currencies);
    filtersData.languages = generateLanguagesFilterData(filtersData.languages, languages);
    filtersData.regions = generateRegionsFilterData(filtersData.regions, region);
  });
  return {
    currencies: (0, _orderBy2["default"])(filtersData.currencies, ['count'], ['desc']),
    languages: (0, _orderBy2["default"])(filtersData.languages, ['count'], ['desc']),
    regions: (0, _orderBy2["default"])(filtersData.regions, ['count'], ['desc'])
  };
}
/**
 * generate currencies filter data
 * @param {Array<Object>} filterData
 * @param {Array<String>} currencies
 * @returns {Array<Object>}
 */


function generateCurrenciesFilterData(filterData, currencies) {
  if (currencies.length === 0) return filterData;
  var data = (0, _toConsumableArray2["default"])(filterData);
  currencies.forEach(function (currency) {
    var matchedFilter = (0, _find2["default"])(data, {
      value: currency
    });

    if (!matchedFilter) {
      data = data.concat({
        groupId: 'currencies',
        value: currency,
        count: 0
      });
    }

    data = data.map(function (filter) {
      return filter.value === currency ? (0, _objectSpread2["default"])({}, filter, {
        count: filter.count + 1
      }) : filter;
    });
  });
  return data;
}
/**
 * generate languages filter data
 * @param {Array<Object>} filterData
 * @param {Array<String>} languages
 * @returns {Array<Object>}
 */


function generateLanguagesFilterData(filterData, languages) {
  if (languages.length === 0) return filterData;
  var data = (0, _toConsumableArray2["default"])(filterData);
  languages.forEach(function (language) {
    var matchedFilter = (0, _find2["default"])(data, {
      value: language
    });

    if (!matchedFilter) {
      data = data.concat({
        groupId: 'languages',
        value: language,
        count: 0
      });
    }

    data = data.map(function (filter) {
      return filter.value === language ? (0, _objectSpread2["default"])({}, filter, {
        count: filter.count + 1
      }) : filter;
    });
  });
  return data;
}
/**
 * generate regions filter data
 * @param {Array<Object>} filterData
 * @param {String} region
 * @returns {Array<Object>}
 */


function generateRegionsFilterData(filterData, region) {
  if (!region || !region.length) return filterData;
  var matchedFilter = (0, _find2["default"])(filterData, {
    value: region
  });

  if (!matchedFilter) {
    return filterData.concat({
      groupId: 'regions',
      value: region,
      count: 1
    });
  }

  return filterData.map(function (filter) {
    return filter.value === region ? (0, _objectSpread2["default"])({}, filter, {
      count: filter.count + 1
    }) : filter;
  });
}